%global modname ipykernel

Name:           python-%{modname}
Version:        5.1.2
Release:        1%{?dist}
Summary:        IPython Kernel for Jupyter
License:        BSD
URL:            https://github.com/ipython/%{modname}
Source0:        https://github.com/ipython/%{modname}/archive/v%{version}/%{modname}-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  python3-sphinx
BuildRequires:  python3-sphinxcontrib-github-alt

%global _description \
This package provides the IPython kernel for Jupyter.

%description %{_description}

%package -n python%{python3_pkgversion}-%{modname}
Summary:        %{summary}
%{?python_provide:%python_provide python%{python3_pkgversion}-%{modname}}
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-docs
BuildRequires:  python%{python3_pkgversion}-ipython >= 5
BuildRequires:  python%{python3_pkgversion}-ipython-doc
BuildRequires:  python%{python3_pkgversion}-jupyter-client
BuildRequires:  python-jupyter-client-doc
BuildRequires:  python%{python3_pkgversion}-traitlets >= 4.1.0
BuildRequires:  python%{python3_pkgversion}-tornado >= 4.2
BuildRequires:  python%{python3_pkgversion}-nose
BuildRequires:  python%{python3_pkgversion}-nose_warnings_filters
BuildRequires:  python%{python3_pkgversion}-pytest
BuildRequires:  python%{python3_pkgversion}-numpy
Requires:       python-jupyter-filesystem

Recommends:     python%{python3_pkgversion}-matplotlib
Recommends:     python%{python3_pkgversion}-numpy
Recommends:     python%{python3_pkgversion}-pandas
Recommends:     python%{python3_pkgversion}-scipy
Recommends:     python%{python3_pkgversion}-pillow

%description -n python%{python3_pkgversion}-%{modname} %{_description}

Python 3 version.

%package doc
Summary:        Documentation for %{name}

%description    doc
This package contains the documentation of %{name}.

%prep
%autosetup -p1 -n %{modname}-%{version}

# Use local objects.inv for intersphinx:
sed -e "s|\(('https://docs.python.org/3/', \)None)|\1'/usr/share/doc/python3-docs/html/objects.inv')|" \
    -e "s|\(('https://ipython.readthedocs.io/en/latest', \)None)|\1'/usr/share/doc/python3-ipython-doc/html/objects.inv')|" \
    -e "s|\(('https://jupyter.readthedocs.io/en/latest', \)None)|\1'/usr/share/doc/python-jupyter-client/html/objects.inv')|" \
    -i docs/conf.py

%build
%py3_build

make %{?_smp_mflags} -C docs html

%install
%py3_install
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -fpavr docs/_build/html %{buildroot}%{_docdir}/%{name}
rm %{buildroot}%{_docdir}/%{name}/html/.buildinfo

# Install the kernel so it can be found
# See https://bugzilla.redhat.com/show_bug.cgi?id=1327979#c19
%{__python3} -m ipykernel install --prefix %{buildroot}%{_prefix}
ls %{buildroot}%{_datadir}/jupyter/kernels/python3/
cat %{buildroot}%{_datadir}/jupyter/kernels/python3/kernel.json


%check
%{__python3} -m pytest ipykernel


%files -n python%{python3_pkgversion}-%{modname}
%license COPYING.md
%doc CONTRIBUTING.md MANIFEST.in README.md
%{python3_sitelib}/%{modname}
%{python3_sitelib}/%{modname}_launcher.py
%{python3_sitelib}/%{modname}*.egg-info
%{python3_sitelib}/__pycache__/%{modname}*
%{_datadir}/jupyter/kernels/python3

%files doc
%doc %{_docdir}/%{name}/html


%changelog
* Thu Sep 26 2019 Jerry James <loganjerry@gmail.com> - 5.1.2-1
- Update to 5.1.2 (bz 1742596)
- Drop upstreamed 408 patch
- Drop explicit Provides that are now autogenerated
- Use local objects.inv for intersphinx, add necessary -doc BRs
- Ship this package's objects.inv
- Run all of the tests again

* Sun Aug 18 2019 Miro Hrončok <mhroncok@redhat.com> - 5.1.1-3
- Rebuilt for Python 3.8

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 5.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Mon May 27 2019 Miro Hrončok <mhroncok@redhat.com> - 5.1.1-1
- Update to 5.1.1 (#1710745)

* Tue Feb 12 2019 Miro Hrončok <mhroncok@redhat.com> - 4.10.0-1
- Update to 5.1.0, drop Python 2 package

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 4.8.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 4.8.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Jul 13 2018 Miro Hrončok <mhroncok@redhat.com> - 4.8.2-3
- Don't own /usr/share/jupyter/ and /usr/share/jupyter/kernels/,
  require python-jupyter-filesystem instead (#1589420)

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 4.8.2-2
- Rebuilt for Python 3.7

* Wed May 23 2018 Miro Hrončok <mhroncok@redhat.com> - 4.8.2-1
- Update to 4.8.2 (#1438785)
- Use Python 3 Sphinx to build the docs

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 4.6.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Dec 08 2017 Iryna Shcherbina <ishcherb@redhat.com> - 4.6.0-3
- Fix ambiguous Python 2 dependency declarations
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sun Apr 09 2017 Miro Hrončok <mhroncok@redhat.com> - 4.6.0-1
- Update to 4.6.0
- Recommend some useful packages
- Run the testsuite

* Wed Mar 15 2017 Miro Hrončok <mhroncok@redhat.com> - 4.5.2-6
- Package the kernel json files

* Wed Mar 8 2017 Orion Poplawski <orion@cora.nwra.com> - 4.5.2-5
- Add missing requires (bug #1430480)

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.5.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Dec 27 2016 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 4.5.2-3
- Preseve timestamp of installed files (#1406958#c7)

* Mon Dec 26 2016 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 4.5.2-2
- Use proper Source0 format (#1406958#c4)
- Do parallel html make (#1406958#c4)

* Thu Dec 22 2016 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 4.5.2-1
- Update to latest upstream release.
- Correct removal of unnecessary doc files.

* Wed Nov 16 2016 pcpa <paulo.cesar.pereira.de.andrade@gmail.com> - 4.5.1-1
- Initial package.
